@@ -1,6 +1,6 @@
 /* exif-tag.c
  *
- * Copyright (C) 2001 Lutz Mller <lutz@users.sourceforge.net>
+ * Copyright  2001 Lutz Mller <lutz@users.sourceforge.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -18,30 +18,12 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include <config.h>
+#include "config.h"
 #include "exif-tag.h"
+#include "i18n.h"
 
 #include <stdlib.h>
 
-#ifdef ENABLE_NLS
-#  include <libintl.h>
-#  undef _
-#  define _(String) dgettext (PACKAGE, String)
-#  ifdef gettext_noop
-#    define N_(String) gettext_noop (String)
-#  else
-#    define N_(String) (String)
-#  endif
-#else
-#  define textdomain(String) (String)
-#  define gettext(String) (String)
-#  define dgettext(Domain,Message) (Message)
-#  define dcgettext(Domain,Message,Type) (Message)
-#  define bindtextdomain(Domain,Directory) (Domain)
-#  define _(String) (String)
-#  define N_(String) (String)
-#endif
-
 static struct {
 	ExifTag tag;
 	const char *name;
@@ -84,12 +66,12 @@ static struct {
 	 N_("Image Description"),
 	 N_("A character string giving the title of the image. It may be "
 	    "a comment such as \"1988 company picnic\" or "
-	    "the like. Two-byte character codes cannot be used. "
-	    "When a 2-byte code is necessary, the Exif Private tag "
+	    "the like. Two-bytes character codes cannot be used. "
+	    "When a 2-bytes code is necessary, the Exif Private tag "
 	    "<UserComment> is to be used.")},
 	{EXIF_TAG_MAKE, "Make", N_("Manufacturer"),
 	 N_("The manufacturer of the recording "
-	    "equipment. This is the manuracturer of the DSC, scanner, "
+	    "equipment. This is the manufacturer of the DSC, scanner, "
 	    "video digitizer or other equipment that generated the "
 	    "image. When the field is left blank, it is treated as "
 	    "unknown.")},
@@ -606,7 +588,7 @@ exif_tag_get_title (ExifTag tag)
 {
 	unsigned int i;
 
-	bindtextdomain (PACKAGE, LIBEXIF_LOCALEDIR);
+	bindtextdomain (GETTEXT_PACKAGE, LIBEXIF_LOCALEDIR);
 
 	for (i = 0; ExifTagTable[i].title; i++)
 		if (ExifTagTable[i].tag == tag)
@@ -620,7 +602,7 @@ exif_tag_get_description (ExifTag tag)
 {
 	unsigned int i;
 
-	bindtextdomain (PACKAGE, LIBEXIF_LOCALEDIR);
+	bindtextdomain (GETTEXT_PACKAGE, LIBEXIF_LOCALEDIR);
 
 	for (i = 0; ExifTagTable[i].description; i++)
 		if (ExifTagTable[i].tag == tag)
