@@ -1,6 +1,6 @@
 /* test-mem.c
  *
- * Copyright (C) 2002 Lutz Mller <lutz@users.sourceforge.net>
+ * Copyright  2002 Lutz Mller <lutz@users.sourceforge.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -18,13 +18,12 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include <config.h>
+#include "config.h"
+#include "exif-data.h"
+#include "exif-ifd.h"
 
 #include <stdio.h>
 
-#include <libexif/exif-data.h>
-#include <libexif/exif-ifd.h>
-
 int
 main (int argc, char **argv)
 {
